@@ -5,6 +5,7 @@
 ##################################################################################################
 import os
 import math
+import fnmatch
 from typing import List, Optional
 
 import ROOT
@@ -260,11 +261,13 @@ class ExtendedModel(object):
         set_parameters = []
         available_parameters = [param.GetName() for param in source]
         for name in param_dict:
-            if name in available_parameters:
-                ExtendedModel._set_parameter(source[name], param_dict[name], mode=mode, param_str=param_str)
-                set_parameters.append(source[name])
-            else:
+            selected_params = [param for param in available_parameters if fnmatch.fnmatch(param, name)]
+            if not selected_params:
                 print('WARNING: Parameter "{}" does not exist. No modification will be made.'.format(name))
+            for param_name in selected_params:
+                ExtendedModel._set_parameter(source[param_name], param_dict[name], mode=mode, param_str=param_str)
+                set_parameters.append(source[param_name])
+
         return set_parameters
     
     @staticmethod
@@ -305,7 +308,7 @@ class ExtendedModel(object):
                 param.setMax(v_max)
                 print('INFO: Set {} "{}" max value to ({},{})'.format(param_str, name, v_max))
         if new_value != old_value:
-            param.setVal(new_Val)              
+            param.setVal(new_value)              
             print('INFO: Set {} "{}" value to {}'.format(param_str, name, new_value))
         if mode=='fix':
             param.setConstant(1)
